@@ -1,5 +1,5 @@
 package Net::Kubernetes::Namespace;
-$Net::Kubernetes::Namespace::VERSION = '1.05';
+$Net::Kubernetes::Namespace::VERSION = '1.06';
 # ABSTRACT: Provides access to kubernetes respources within a single namespace.
 
 use Moose;
@@ -64,6 +64,33 @@ sub get_replica_set {
 }
 alias get_rs => 'get_replica_set';
 
+sub get_role {
+    my ($self, $name) = @_;
+    Net::Kubernetes::Exception->throw(message => "Missing required parameter 'name'") if (!defined $name || !length $name);
+    return $self->get_resource_by_name($name, 'role');
+}
+
+sub get_role_binding {
+    my ($self, $name) = @_;
+    Net::Kubernetes::Exception->throw(message => "Missing required parameter 'name'") if (!defined $name || !length $name);
+    return $self->get_resource_by_name($name, 'rolebinding');
+}
+
+sub get_service_account{
+    my ($self, $name) = @_;
+    Net::Kubernetes::Exception->throw(message => "Missing required parameter 'name'") if (!defined $name || !length $name);
+    return $self->get_resource_by_name($name, 'serviceaccount');
+}
+
+sub delete {
+    my ($self) = @_;
+    my ($res) = $self->ua->request($self->create_request(DELETE => $self->path));
+    if ($res->is_success) {
+        return 1;
+    }
+    return 0;
+}
+
 return 42;
 
 __END__
@@ -78,7 +105,7 @@ Net::Kubernetes::Namespace - Provides access to kubernetes respources within a s
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head2 $ns->get_pod('my-pod-name')
 
