@@ -1,5 +1,5 @@
 package Net::Kubernetes::Role::ResourceLister;
-$Net::Kubernetes::Role::ResourceLister::VERSION = '1.05';
+$Net::Kubernetes::Role::ResourceLister::VERSION = '1.06';
 # ABSTRACT: Role to give access to list_* methods.
 
 use Moose::Role;
@@ -72,6 +72,30 @@ sub list_replica_sets {
     return $self->_retrieve_list('ReplicaSet', %options);
 }
 
+
+sub list_roles {
+    my $self = shift;
+    my %options = $self->_norm_options(@_);
+
+    return $self->_retrieve_list('Role', %options);
+}
+
+
+sub list_role_bindings {
+    my $self = shift;
+    my %options = $self->_norm_options(@_);
+
+    return $self->_retrieve_list('RoleBinding', %options);
+}
+
+
+sub list_service_accounts {
+    my $self = shift;
+    my %options = $self->_norm_options(@_);
+
+    return $self->_retrieve_list('ServiceAccount', %options);
+}
+
 sub _retrieve_list {
     my $self          = shift;
     my $resource_kind = shift;
@@ -131,7 +155,7 @@ Net::Kubernetes::Role::ResourceLister - Role to give access to list_* methods.
 
 =head1 VERSION
 
-version 1.05
+version 1.06
 
 =head2 list_pods([label=>{label=>value}], [fields=>{field=>value}])
 
@@ -173,6 +197,18 @@ returns a list of L<Net::Kubernetes::Resource::ReplicaSet>s
 
 returns a list of L<Net::Kubernetes::Resource::ReplicaSet>s
 
+=head2 list_roles([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::Role>s
+
+=head2 list_role_bindings([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::RoleBinding>s
+
+=head2 list_service_accounts([label=>{label=>value}], [fields=>{field=>value}])
+
+returns a list of L<Net::Kubernetes::Resource::ServiceAccount>s
+
 =head1 AUTHOR
 
 Dave Mueller <dave@perljedi.com>
